@@ -319,8 +319,8 @@ bB = functions()
 def init():
     #Prints the Information about the Local Master and the connected Bricks to him
     for n in range(connect.number):
-        print(f'\nNode {n + 1} is connected with the local master: {local.id[n] // 1000}-{local.id[n] % 1000}')
+        print(f'\nNode {n + 1} is connected with the local master: {local.id[n] // 1000}-{local.id[n] % 1000} with Software Version: {local.soft_ver[n]}')
         print(f'With following modules:')
         for i in range(local.number_of_bricks[n]):
-            print(f'{i + 1}: {slave.id[n, i] // 1000}-{slave.id[n, i] % 1000}')
+            print(f'{i + 1}: {slave.id[n, i] // 1000}-{slave.id[n, i] % 1000} with Hardware Revision: {slave.hard_rev[n, 1]')
     print("To abort the program please press STRG + C\n\n")
